@@ -1,5 +1,5 @@
 /* the Music Player Daemon (MPD)
- * (c)2003-2006 by Warren Dukes (warren.dukes@gmail.com)
+ * Copyright (C) 2003-2007 by Warren Dukes (warren.dukes@gmail.com)
  * This project's homepage is: http://www.musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -96,4 +96,14 @@ void initInputPlugins(void);
 /* this is where we "unload" all the "plugins" */
 void finishInputPlugins(void);
 
+extern InputPlugin mp3Plugin;
+extern InputPlugin oggvorbisPlugin;
+extern InputPlugin flacPlugin;
+extern InputPlugin oggflacPlugin;
+extern InputPlugin audiofilePlugin;
+extern InputPlugin mp4Plugin;
+extern InputPlugin mpcPlugin;
+extern InputPlugin aacPlugin;
+extern InputPlugin modPlugin;
+
 #endif
