@@ -21,10 +21,13 @@
 
 #include "../inputPlugin.h"
 
-#if defined(HAVE_OGGFLAC) || defined(HAVE_OGGVORBIS)
+#include "_flac_common.h"
+#include "_ogg_common.h"
+
+#if defined(HAVE_OGGFLAC) || defined(HAVE_OGGVORBIS) || \
+  (defined(FLAC_API_VERSION_CURRENT) && FLAC_API_VERSION_CURRENT > 7)
 
 #include "../utils.h"
-#include "_ogg_common.h"
 
 #include <string.h>
 
