@@ -1,5 +1,5 @@
 /* the Music Player Daemon (MPD)
- * (c)2003-2006 by Warren Dukes (warren.dukes@gmail.com)
+ * Copyright (C) 2003-2007 by Warren Dukes (warren.dukes@gmail.com)
  * This project's homepage is: http://www.musicpd.org
  * 
  * libaudiofile (wave) support added by Eric Wong <normalperson@yhbt.net>
@@ -183,17 +183,6 @@ InputPlugin audiofilePlugin = {
 
 #else
 
-InputPlugin audiofilePlugin = {
-	NULL,
-	NULL,
-	NULL,
-	NULL,
-	NULL,
-	NULL,
-	NULL,
-	0,
-	NULL,
-	NULL
-};
+InputPlugin audiofilePlugin;
 
 #endif /* HAVE_AUDIOFILE */
