@@ -1,5 +1,5 @@
 /* the Music Player Daemon (MPD)
- * (c)2003-2006 by Warren Dukes (warren.dukes@gmail.com)
+ * Copyright (C) 2003-2007 by Warren Dukes (warren.dukes@gmail.com)
  * This project's homepage is: http://www.musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -31,6 +31,7 @@
 #include "../utils.h"
 #include "../replayGain.h"
 #include "../tag.h"
+#include "../conf.h"
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -55,6 +56,10 @@
 /* the number of samples of silence the decoder inserts at start */
 #define DECODERDELAY 529
 
+#define DEFAULT_GAPLESS_MP3_PLAYBACK 1
+
+static int gaplessPlayback;
+
 /* this is stolen from mpg321! */
 struct audio_dither {
 	mad_fixed_t error[3];
@@ -113,6 +118,14 @@ static signed long audio_linear_dither(unsigned int bits, mad_fixed_t sample,
 
 /* end of stolen stuff from mpg321 */
 
+static int mp3_plugin_init(void)
+{
+	gaplessPlayback = getBoolConfigParam(CONF_GAPLESS_MP3_PLAYBACK);
+	if (gaplessPlayback == -1) gaplessPlayback = DEFAULT_GAPLESS_MP3_PLAYBACK;
+	else if (gaplessPlayback < 0) exit(EXIT_FAILURE);
+	return 1;
+}
+
 /* decoder stuff is based on madlld */
 
 #define MP3_DATA_OUTPUT_BUFFER_SIZE 4096
@@ -679,7 +692,8 @@ static int decodeFirstFrame(mp3DecodeData * data, DecoderControl * dc,
 		data->foundXing = 1;
 		data->muteFrame = MUTEFRAME_SKIP;
 
-		if (parse_lame(&lame, &ptr, &bitlen)) {
+		if (gaplessPlayback && data->inStream->seekable &&
+		    parse_lame(&lame, &ptr, &bitlen)) {
 			data->dropSamplesAtStart = lame.encoderDelay + DECODERDELAY;
 			data->dropSamplesAtEnd = lame.encoderPadding;
 		}
@@ -759,8 +773,6 @@ static int mp3Read(mp3DecodeData * data, OutputBuffer * cb, DecoderControl * dc,
 		mad_timer_add(&data->timer, (data->frame).header.duration);
 		data->bitRate = (data->frame).header.bitrate;
 		if (data->currentFrame >= data->maxFrames) {
-			/* stop decoding, since Xing maxFrames is accurate */
-			if (data->foundXing) return DECODE_BREAK;
 			data->currentFrame = data->maxFrames - 1;
 		} else {
 			data->highestFrame++;
@@ -811,8 +823,9 @@ static int mp3Read(mp3DecodeData * data, OutputBuffer * cb, DecoderControl * dc,
 			break;
 		} else if ((data->dropFramesAtEnd > 0) && 
 		           (data->currentFrame == (data->maxFrames + 1 - data->dropFramesAtEnd))) {
-			data->dropFramesAtEnd--;
-			break;
+			/* stop decoding, effectively dropping all remaining
+			 * frames */
+			return DECODE_BREAK;
 		}
 
 		if (data->inStream->metaTitle) {
@@ -835,59 +848,43 @@ static int mp3Read(mp3DecodeData * data, OutputBuffer * cb, DecoderControl * dc,
 		for (i = 0; i < (data->synth).pcm.length; i++) {
 			mpd_sint16 *sample;
 
+			samplesLeft--;
+
 			if (!data->decodedFirstFrame &&
 			    (i < data->dropSamplesAtStart)) {
 				continue;
 			} else if (data->dropSamplesAtEnd &&
-			           (data->currentFrame == (data->maxFrames - data->dropFramesAtEnd))) {
-				samplesLeft--;
-				/* stop decoding, since samples were dropped */
-				if (samplesLeft < data->dropSamplesAtEnd)
-					return DECODE_BREAK;
+			           (data->currentFrame == (data->maxFrames - data->dropFramesAtEnd)) &&
+				   (samplesLeft < data->dropSamplesAtEnd)) {
+				/* stop decoding, effectively dropping
+				 * all remaining samples */
+				return DECODE_BREAK;
 			}
 
 			sample = (mpd_sint16 *) data->outputPtr;
 			*sample = (mpd_sint16) audio_linear_dither(16,
-								   (data->
-								    synth).pcm.
-								   samples[0]
-								   [i],
-								   &(data->
-								     dither));
+								   (data->synth).pcm.samples[0][i],
+								   &(data->dither));
 			data->outputPtr += 2;
 
 			if (MAD_NCHANNELS(&(data->frame).header) == 2) {
 				sample = (mpd_sint16 *) data->outputPtr;
 				*sample = (mpd_sint16) audio_linear_dither(16,
-									   (data->
-									    synth).
-									   pcm.
-									   samples
-									   [1]
-									   [i],
-									   &
-									   (data->
-									    dither));
+									   (data->synth).pcm.samples[1][i],
+									   &(data->dither));
 				data->outputPtr += 2;
 			}
 
 			if (data->outputPtr >= data->outputBufferEnd) {
-				long ret;
 				ret = sendDataToOutputBuffer(cb,
 							     data->inStream,
 							     dc,
-							     data->inStream->
-							     seekable,
-							     data->outputBuffer,
-							     data->outputPtr -
+							     data->inStream->seekable,
 							     data->outputBuffer,
+							     data->outputPtr - data->outputBuffer,
 							     data->elapsedTime,
-							     data->bitRate /
-							     1000,
-							     (replayGainInfo !=
-							      NULL) ?
-							     *replayGainInfo :
-							     NULL);
+							     data->bitRate / 1000,
+							     (replayGainInfo != NULL) ? *replayGainInfo : NULL);
 				if (ret == OUTPUT_BUFFER_DC_STOP) {
 					data->flush = 0;
 					return DECODE_BREAK;
@@ -903,21 +900,21 @@ static int mp3Read(mp3DecodeData * data, OutputBuffer * cb, DecoderControl * dc,
 		data->decodedFirstFrame = 1;
 
 		if (dc->seek && data->inStream->seekable) {
-			long i = 0;
+			long j = 0;
 			data->muteFrame = MUTEFRAME_SEEK;
-			while (i < data->highestFrame && dc->seekWhere >
-			       ((float)mad_timer_count(data->times[i],
+			while (j < data->highestFrame && dc->seekWhere >
+			       ((float)mad_timer_count(data->times[j],
 						       MAD_UNITS_MILLISECONDS))
 			       / 1000) {
-				i++;
+				j++;
 			}
-			if (i < data->highestFrame) {
+			if (j < data->highestFrame) {
 				if (seekMp3InputBuffer(data,
-						       data->frameOffset[i]) ==
+						       data->frameOffset[j]) ==
 				    0) {
 					data->outputPtr = data->outputBuffer;
 					clearOutputBuffer(cb);
-					data->currentFrame = i;
+					data->currentFrame = j;
 				} else
 					dc->seekError = 1;
 				data->muteFrame = 0;
@@ -1078,7 +1075,7 @@ static char *mp3_mimeTypes[] = { "audio/mpeg", NULL };
 
 InputPlugin mp3Plugin = {
 	"mp3",
-	NULL,
+	mp3_plugin_init,
 	NULL,
 	NULL,
 	mp3_decode,
@@ -1090,17 +1087,6 @@ InputPlugin mp3Plugin = {
 };
 #else
 
-InputPlugin mp3Plugin = {
-	NULL,
-	NULL,
-	NULL,
-	NULL,
-	NULL,
-	NULL,
-	NULL,
-	0,
-	NULL,
-	NULL
-};
+InputPlugin mp3Plugin;
 
-#endif
+#endif /* HAVE_MAD */
