@@ -1,5 +1,5 @@
 /* the Music Player Daemon (MPD)
- * (c)2003-2006 by Warren Dukes (warren.dukes@gmail.com)
+ * Copyright (C) 2003-2007 by Warren Dukes (warren.dukes@gmail.com)
  * This project's homepage is: http://www.musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -42,6 +42,7 @@
 #include "../config.h"
 #include "utils.h"
 #include "normalize.h"
+#include "zeroconf.h"
 
 #include <stdio.h>
 #include <sys/select.h>
@@ -65,7 +66,6 @@ typedef struct _Options {
 	int daemon;
 	int stdOutput;
 	int createDB;
-	int updateDB;
 	int verbose;
 } Options;
 
@@ -126,7 +126,6 @@ static void usage(char *argv[])
 	    ("   --no-create-db     don't create database, even if it doesn't exist\n");
 	ERROR("   --no-daemon        don't detach from console\n");
 	ERROR("   --stdout           print messages to stdout and stderr\n");
-	/*ERROR("   --update-db        create database and exit\n"); */
 	ERROR("   --verbose          verbose logging\n");
 	ERROR("   --version          prints version information\n");
 }
@@ -135,7 +134,7 @@ static void version(void)
 {
 	LOG("mpd (MPD: Music Player Daemon) %s\n", VERSION);
 	LOG("\n");
-	LOG("Copyright (C) 2003-2006 Warren Dukes <warren.dukes@gmail.com>\n");
+	LOG("Copyright (C) 2003-2007 Warren Dukes <warren.dukes@gmail.com>\n");
 	LOG("This is free software; see the source for copying conditions.  There is NO\n");
 	LOG("warranty; not even MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n");
 	LOG("\n");
@@ -158,7 +157,6 @@ static void parseOptions(int argc, char **argv, Options * options)
 	options->daemon = 1;
 	options->stdOutput = 0;
 	options->createDB = 0;
-	options->updateDB = 0;
 	options->kill = 0;
 
 	if (argc > 1) {
@@ -248,15 +246,13 @@ static void changeToUser(void)
 		/* get uid */
 		struct passwd *userpwd;
 		if ((userpwd = getpwnam(param->value)) == NULL) {
-			ERROR("no such user \"%s\" at line %i\n", param->value,
+			FATAL("no such user \"%s\" at line %i\n", param->value,
 			      param->line);
-			exit(EXIT_FAILURE);
 		}
 
 		if (setgid(userpwd->pw_gid) == -1) {
-			ERROR("cannot setgid for user \"%s\" at line %i: %s\n",
+			FATAL("cannot setgid for user \"%s\" at line %i: %s\n",
 			      param->value, param->line, strerror(errno));
-			exit(EXIT_FAILURE);
 		}
 #ifdef _BSD_SOURCE
 		/* init suplementary groups 
@@ -271,10 +267,9 @@ static void changeToUser(void)
 
 		/* set uid */
 		if (setuid(userpwd->pw_uid) == -1) {
-			ERROR("cannot change to uid of user "
+			FATAL("cannot change to uid of user "
 			      "\"%s\" at line %i: %s\n",
 			      param->value, param->line, strerror(errno));
-			exit(EXIT_FAILURE);
 		}
 
 		/* this is needed by libs such as arts */
@@ -288,10 +283,9 @@ static void openDB(Options * options, char *argv0)
 {
 	if (options->createDB > 0 || readDirectoryDB() < 0) {
 		if (options->createDB < 0) {
-			ERROR("can't open db file and using \"--no-create-db\""
-			      " command line option\n");
-			ERROR("try running \"%s --create-db\"\n", argv0);
-			exit(EXIT_FAILURE);
+			FATAL("can't open db file and using "
+			      "\"--no-create-db\" command line option\n"
+			      "try running \"%s --create-db\"\n", argv0);
 		}
 		flushWarningLog();
 		if (checkDirectoryDB() < 0)
@@ -302,11 +296,6 @@ static void openDB(Options * options, char *argv0)
 		if (options->createDB)
 			exit(EXIT_SUCCESS);
 	}
-	if (options->updateDB) {
-		flushWarningLog();
-		updateMp3Directory();
-		exit(EXIT_SUCCESS);
-	}
 }
 
 static void daemonize(Options * options)
@@ -320,11 +309,9 @@ static void daemonize(Options * options)
 		DEBUG("opening pid file\n");
 		fp = fopen(pidFileParam->value, "w+");
 		if (!fp) {
-			ERROR
-			    ("could not open %s \"%s\" (at line %i) for writing: %s\n",
+			FATAL("could not open %s \"%s\" (at line %i) for writing: %s\n",
 			     CONF_PID_FILE, pidFileParam->value,
 			     pidFileParam->line, strerror(errno));
-			exit(EXIT_FAILURE);
 		}
 	}
 
@@ -336,18 +323,15 @@ static void daemonize(Options * options)
 		if (pid > 0)
 			_exit(EXIT_SUCCESS);
 		else if (pid < 0) {
-			ERROR("problems fork'ing for daemon!\n");
-			exit(EXIT_FAILURE);
+			FATAL("problems fork'ing for daemon!\n");
 		}
 
 		if (chdir("/") < 0) {
-			ERROR("problems changing to root directory\n");
-			exit(EXIT_FAILURE);
+			FATAL("problems changing to root directory\n");
 		}
 
 		if (setsid() < 0) {
-			ERROR("problems setsid'ing\n");
-			exit(EXIT_FAILURE);
+			FATAL("problems setsid'ing\n");
 		}
 
 		fflush(NULL);
@@ -355,8 +339,7 @@ static void daemonize(Options * options)
 		if (pid > 0)
 			_exit(EXIT_SUCCESS);
 		else if (pid < 0) {
-			ERROR("problems fork'ing for daemon!\n");
-			exit(EXIT_FAILURE);
+			FATAL("problems fork'ing for daemon!\n");
 		}
 
 		DEBUG("daemonized!\n");
@@ -388,26 +371,22 @@ static void killFromPidFile(char *cmd, int killOption)
 	int pid;
 
 	if (!pidFileParam) {
-		ERROR("no pid_file specified in the config file\n");
-		exit(EXIT_FAILURE);
+		FATAL("no pid_file specified in the config file\n");
 	}
 
 	fp = fopen(pidFileParam->value, "r");
 	if (!fp) {
-		ERROR("unable to open %s \"%s\": %s\n",
+		FATAL("unable to open %s \"%s\": %s\n",
 		      CONF_PID_FILE, pidFileParam->value, strerror(errno));
-		exit(EXIT_FAILURE);
 	}
 	if (fscanf(fp, "%i", &pid) != 1) {
-		ERROR("unable to read the pid from file \"%s\"\n",
+		FATAL("unable to read the pid from file \"%s\"\n",
 		      pidFileParam->value);
-		exit(EXIT_FAILURE);
 	}
 	fclose(fp);
 
 	if (kill(pid, SIGTERM)) {
-		ERROR("unable to kill proccess %i: %s\n", pid, strerror(errno));
-		exit(EXIT_FAILURE);
+		FATAL("unable to kill proccess %i: %s\n", pid, strerror(errno));
 	}
 	exit(EXIT_SUCCESS);
 }
@@ -430,7 +409,7 @@ int main(int argc, char *argv[])
 	initTagConfig();
 	initLog(options.verbose);
 
-	if (options.createDB <= 0 && !options.updateDB)
+	if (options.createDB <= 0)
 		listenOnPort();
 
 	changeToUser();
@@ -450,6 +429,7 @@ int main(int argc, char *argv[])
 	initAudioDriver();
 	initVolume();
 	initInterfaces();
+	initZeroconf();
 	initReplayGainState();
 	initNormalization();
 	initInputStream();
@@ -475,6 +455,7 @@ int main(int argc, char *argv[])
 
 	write_state_file();
 	playerKill();
+	finishZeroconf();
 	freeAllInterfaces();
 	closeAllListenSockets();
 	finishPlaylist();
