@@ -1,5 +1,5 @@
 /* the Music Player Daemon (MPD)
- * (c)2003-2006 by Warren Dukes (warren.dukes@gmail.com)
+ * Copyright (C) 2003-2007 by Warren Dukes (warren.dukes@gmail.com)
  * This project's homepage is: http://www.musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -28,8 +28,6 @@
 #include "myfprintf.h"
 
 #define SONG_KEY	"key: "
-#define SONG_FILE	"file: "
-#define SONG_TIME	"Time: "
 #define SONG_MTIME	"mtime: "
 
 #include <stdlib.h>
@@ -253,10 +251,8 @@ void readSongInfoIntoList(FILE * fp, SongList * list, Directory * parentDir)
 			song->type = SONG_TYPE_FILE;
 			song->parentDir = parentDir;
 		} else if (0 == strncmp(SONG_FILE, buffer, strlen(SONG_FILE))) {
-			if (!song) {
-				ERROR("Problems reading song info\n");
-				exit(EXIT_FAILURE);
-			}
+			if (!song)
+				FATAL("Problems reading song info\n");
 			/* we don't need this info anymore
 			   song->url = xstrdup(&(buffer[strlen(SONG_FILE)]));
 			 */
@@ -275,10 +271,8 @@ void readSongInfoIntoList(FILE * fp, SongList * list, Directory * parentDir)
 			song->mtime = atoi(&(buffer[strlen(SONG_MTIME)]));
 		}
 		/* ignore empty lines (starting with '\0') */
-		else if (*buffer) {
-			ERROR("songinfo: unknown line in db: %s\n", buffer);
-			exit(EXIT_FAILURE);
-		}
+		else if (*buffer)
+			FATAL("songinfo: unknown line in db: %s\n", buffer);
 	}
 
 	if (song) {
@@ -322,9 +316,9 @@ int updateSongInfo(Song * song)
  * 	we free and recreate this memory we make sure to print it correctly*/
 char *getSongUrl(Song * song)
 {
-	static char *buffer = NULL;
-	static int bufferSize = 0;
-	static Song *lastSong = NULL;
+	static char *buffer;
+	static int bufferSize;
+	static Song *lastSong;
 	int slen;
 	int dlen;
 	int size;
